@@ -52,20 +52,29 @@ ____
         >>> search.get_subjects()
 """
 
-__version__ = '0.4.1a'
+__version__ = '0.5.0'
 
 import os
 import sys
 
-module_path = os.path.dirname(os.path.abspath(__file__))
+if os.path.join(os.path.dirname(os.path.abspath(__file__)), 'externals') \
+    not in sys.path:
+    sys.path.append(os.path.join(os.path.dirname(os.path.abspath(__file__)), 
+                                                               'externals'))
 
-if os.path.join(module_path, 'externals') not in sys.path:
-    sys.path.append(os.path.join(module_path, 'externals'))
-
-from .xobject import Interface, SearchManager, Search, CacheManager, \
-                     ResourceObject, Project, Subject, Experiment, Scan, \
+import httplib2
+from .restapi import Interface, CacheManager, \
+                     ResourceObject, CollectionObject, \
+                     Project, Subject, Experiment, Scan, \
                      Resource, File, Attrib
 
-from .xobject import module_path as xnatrest_path
-from .xobject import shortcuts_path as xnatrest_shortcuts
+from .search import SearchManager
+
+from .restapi import shortcuts_path as xnatrest_shortcuts
+from .restapi import xtype_path as xnatrest_xtype
+from .restapi import _xtypes as xtypes
+from .restapi import _shortcuts as shortcuts
+
+from .jsontable import JsonTable
+
 
